==> flink-1.15.0-src.tgz: flink-1.15.0/flink-libraries/flink-state-processing-api/src/main/java/org/apache/flink/state/api/runtime/MutableConfig.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.state.api.runtime;

import org.apache.flink.annotation.Internal;
import org.apache.flink.configuration.Configuration;
import org.apache.flink.configuration.ReadableConfig;
import org.apache.flink.configuration.UnmodifiableConfiguration;

/** A utility for creating a mutable {@link Configuration} from a {@link ReadableConfig}. */
@Internal
public final class MutableConfig {

    private MutableConfig() {}

    /**
     * Creates a new {@link Configuration}.
     *
     * @param config A readable configuration.
     * @return A mutable Configuration.
     */
    public static Configuration of(ReadableConfig config) {
        if (!(config instanceof UnmodifiableConfiguration)) {
            throw new IllegalStateException(
                    "Unexpected implementation of ReadableConfig: " + config.getClass());
        }

        return new Configuration((UnmodifiableConfiguration) config);
    }
}

==> flink-1.20.2-src.tgz: flink-1.20.2/flink-libraries/flink-state-processing-api/src/main/java/org/apache/flink/state/api/runtime/MutableConfig.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.state.api.runtime;

import org.apache.flink.annotation.Internal;
import org.apache.flink.configuration.Configuration;
import org.apache.flink.configuration.ReadableConfig;

/** A utility for creating a mutable {@link Configuration} from a {@link ReadableConfig}. */
@Internal
public final class MutableConfig {

    private MutableConfig() {}

    /**
     * Creates a new {@link Configuration}.
     *
     * @param config A readable configuration.
     * @return A mutable Configuration.
     */
    public static Configuration of(ReadableConfig config) {
        if (!(config instanceof Configuration)) {
            throw new IllegalStateException(
                    "Unexpected implementation of ReadableConfig: " + config.getClass());
        }
        return new Configuration((Configuration) config);
    }
}
